import 'package:flutter/material.dart';

/// Generates a color based on a string input (typically a name)
Color generateColorFromName(String name) {
  if (name.isEmpty) return Colors.grey;
  
  // Use the hashCode of the name to generate a consistent color
  int hash = name.hashCode;
  
  // Use the hash to generate RGB values
  final r = (hash & 0xFF0000) >> 16;
  final g = (hash & 0x00FF00) >> 8;
  final b = hash & 0x0000FF;
  
  // Create a color with these RGB values
  return Color.fromARGB(255, r, g, b);
}

/// Darkens a color by a percentage (0.0 to 1.0)
Color darken(Color color, [double amount = 0.3]) {
  assert(amount >= 0 && amount <= 1);
  
  final hsl = HSLColor.fromColor(color);
  final darkened = hsl.withLightness((hsl.lightness - amount).clamp(0.0, 1.0));
  
  return darkened.toColor();
}

/// Lightens a color by a percentage (0.0 to 1.0)
Color lighten(Color color, [double amount = 0.3]) {
  assert(amount >= 0 && amount <= 1);
  
  final hsl = HSLColor.fromColor(color);
  final lightened = hsl.withLightness((hsl.lightness + amount).clamp(0.0, 1.0));
  
  return lightened.toColor();
}
